#
# spec file for package python-Jinja2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           python-Jinja2
Version:        2.6
Release:        2.15.12
Summary:        A fast and easy to use template engine written in pure Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://jinja.pocoo.org/
Source:         http://pypi.python.org/packages/source/J/Jinja2/Jinja2-%{version}.tar.gz
# UPSTREAM backport
Patch1:         0001-Fixed-a-security-issue-with-temporary-files-on-the-f.patch
Patch2:         0002-Fix-CVE-2014-0012.patch
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
BuildRequires:  python-devel
BuildRequires:  python-distribute
Provides:       python-jinja2 = %{version}
Obsoletes:      python-jinja2 < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Jinja2 is a template engine written in pure Python.  It provides a
Django inspired non-XML syntax but supports inline expressions and an
optional sandboxed environment.  Here a small example of a Jinja
template:

{% extends 'base.html' %} {% block title %}Memberlist{% endblock %} {%
block content %} <ul> {% for user in users %} <li><a href=" user.url ">
user.username </a></li> {% endfor %} </ul> {% endblock %}



%package vim
Summary:        Jinja2 syntax files for Vim
License:        BSD-3-Clause
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description vim
Vim syntax highlighting scheme for Jinja2 templates.



%package emacs
Summary:        Jinja2 syntax files for Emacs
License:        BSD-3-Clause
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description emacs
Emacs syntax highlighting scheme for Jinja2 templates.



%prep
%setup -q -n Jinja2-%{version}
%patch1 -p1
%patch2 -p1

%build
python setup.py build
sed -i 's/\r$//' LICENSE # Fix wrong EOL encoding

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -Dm644 ext/Vim/jinja.vim %{buildroot}%{_datadir}/vim/site/syntax/jinja.vim # Install VIM syntax file
install -Dm644 ext/jinja.el %{buildroot}%{_datadir}/emacs/site-lisp/jinja.el # Install Emacs syntax file
%if 0%{?suse_version} > 1010
%fdupes %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE artwork examples ext/JinjaTemplates.tmbundle.tar.gz
%{python_sitelib}/*

%files vim
%defattr(-,root,root,-)
%{_datadir}/vim

%files emacs
%defattr(-,root,root,-)
%{_datadir}/emacs/site-lisp/jinja.el

%changelog
* Mon Jul 21 2014 bwiedemann@suse.com
- Add checks for the per-user temporary directory.
  Add 0002-Fix-CVE-2014-0012.patch (CVE-2014-0012)
* Thu Jul 10 2014 bwiedemann@suse.com
- Fixed a security issue with temporary files (bnc#858239, CVE-2014-1402)
* Thu Feb 23 2012 saschpe@suse.de
- Simplified macro usage
* Thu Sep 22 2011 saschpe@suse.de
- Split of 'vim' and 'emacs' sub-packages that contain syntax highlighting
  support for both editors
* Thu Sep 22 2011 saschpe@suse.de
- Set license to BSD-3-Clause (SPDX style)
- Require python-distribute instead of python-setuptools
* Tue Sep 20 2011 saschpe@suse.de
- Update to version 2.6:
  * internal attributes now raise an internal attribute error now instead
    of returning an undefined.  This fixes problems when passing undefined
    objects to Python semantics expecting APIs.
  * traceback support now works properly for PyPy.  (Tested with 1.4)
  * implemented operator intercepting for sandboxed environments.  This
    allows application developers to disable builtin operators for better
    security.  (For instance limit the mathematical operators to actual
    integers instead of longs)
  * groupby filter now supports dotted notation for grouping by attributes
    of attributes.
  * scoped blocks not properly treat toplevel assignments and imports.
    Previously an import suddenly "disappeared" in a scoped block.
  * automatically detect newer Python interpreter versions before loading code
    from bytecode caches to prevent segfaults on invalid opcodes.  The segfault
    in earlier Jinja2 versions here was not a Jinja2 bug but a limitation in
    the underlying Python interpreter.  If you notice Jinja2 segfaulting in
    earlier versions after an upgrade of the Python interpreter you don't have
    to upgrade, it's enough to flush the bytecode cache.  This just no longer
    makes this necessary, Jinja2 will automatically detect these cases now.
  * the sum filter can now sum up values by attribute.  This is a backwards
    incompatible change.  The argument to the filter previously was the
    optional starting index which defaultes to zero.  This now became the
    second argument to the function because it's rarely used.
  * like sum, sort now also makes it possible to order items by attribute.
  * like sum and sort, join now also is able to join attributes of objects
    as string.
  * the internal eval context now has a reference to the environment.
  * added a mapping test to see if an object is a dict or an object with
    a similar interface.
* Wed Jul 20 2011 saschpe@gmx.de
- Renamed to python-Jinja2
- Fix wrong EOL encodings
* Thu Apr  7 2011 saschpe@suse.de
- Do not require python-setuptools, buildrequires is sufficient
- Removed authors from description
- Changed license to BSD3c
* Sun Dec 12 2010 saschpe@gmx.de
- rpmlint issues cleanup
  * fdupes, tar.bz2 tarball, ...
- package docs again (lost with last revision)
* Sat Dec 11 2010 saschpe@gmx.de
- re-generated spec file with py2pack
  * now builds for Fedora and Mandriva
* Thu Sep 17 2009 alexandre@exatati.com.br
- Update to 2.2.1;
- Fixed changes file name.
* Mon Jun  8 2009 poeml@suse.de
- initial package (2.1.1)
